@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.c,v 1.18 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: bbs_thread_ui.c,v 1.20 2003/11/05 10:22:15 fuyu Exp $
  */
 
 #include "config.h"
@@ -413,6 +413,9 @@ bbs_thread_info_free(BBSThreadGUIInfo *info)
       info->last_mail = NULL;
     }
 
+  if (info->write_dialog != NULL)
+    gtk_widget_destroy(info->write_dialog);
+
   G_FREE(info);
 }
 
@@ -469,7 +472,7 @@ open_bbs_thread(OchushaApplication *application, OchushaBBSThread *thread,
       OchushaAsyncBuffer *buffer;
 
       thread_view = bbs_thread_view_new(thread);
-      gtk_widget_show(thread_view);
+      /*      gtk_widget_show(thread_view); */
 
       job = G_NEW0(WorkerJob, 1);
       job_args = G_NEW0(BBSThreadJobArgs, 1);
@@ -1510,7 +1513,7 @@ render_popup_response(PopupContext *popup_context,
   OchushaApplication *application
     = popup_context->renderer_context.application;
   GtkWidget *view = bbs_thread_view_new(thread);
-  bbs_thread_view_set_wrap_mode(BBS_THREAD_VIEW(view), GTK_WRAP_NONE);
+  gtk_text_view_set_wrap_mode(GTK_TEXT_VIEW(view), GTK_WRAP_NONE);
 
   g_object_set_qdata(G_OBJECT(view), popup_parent_context_id,
 		     popup_context);
@@ -1552,7 +1555,6 @@ render_popup_response(PopupContext *popup_context,
   gtk_widget_show(GTK_WIDGET(popup_context->popup_frame));
 
   popup_context->renderer_context.view = BBS_THREAD_VIEW(view);
-  bbs_thread_view_hide_scrollbar(popup_context->renderer_context.view);
   popup_context->renderer_context.link_text_length = 0;
   popup_context->renderer_context.thread = thread;
 
