@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_ui.h,v 1.7 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: bbs_thread_ui.h,v 1.8 2003/11/04 18:09:57 fuyu Exp $
  */
 
 #ifndef _BBSTHREAD_UI_H_
@@ -76,6 +76,9 @@ typedef struct _BBSThreadGUIInfo
   /* Ǹ˳ưʹߤΥ */
   gint view_ignored;
 
+  /* 񤭹ѥ */
+  GtkWidget *write_dialog;
+
   /* Ǹν񤭹߻̾ */
   gchar *last_name;
 
