@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.c,v 1.13 2003/11/02 21:24:14 fuyu Exp $
+ * $Id: bbs_thread_view.c,v 1.15 2003/11/05 10:22:15 fuyu Exp $
  */
 
 #include "config.h"
@@ -102,7 +102,7 @@ bbs_thread_view_get_type(void)
 	  (GInstanceInitFunc)bbs_thread_view_init,
 	};
 
-      btv_type = g_type_register_static(GTK_TYPE_SCROLLED_WINDOW,
+      btv_type = g_type_register_static(GTK_TYPE_TEXT_VIEW,
 					"BBSThreadView", &btv_info, 0);
     }
 
@@ -128,7 +128,7 @@ enum {
 };
 
 
-static GtkScrolledWindowClass *parent_class = NULL;
+static GtkTextViewClass *parent_class = NULL;
 static gint bbs_thread_view_signals[LAST_SIGNAL] = { 0, 0, 0, 0, 0, 0, 0 };
 static GtkTextTagTable *default_tag_table;
 
@@ -354,6 +354,17 @@ bbs_thread_view_class_init(BBSThreadViewClass *klass)
 			       "scroll_to", 1,
 			       G_TYPE_INT, SCROLL_TO_BUFFER_END);
 
+  gtk_binding_entry_add_signal(binding_set, GDK_space, 0,
+			       "move_cursor", 3,
+			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
+			       G_TYPE_INT, 1,
+			       G_TYPE_BOOLEAN, FALSE);
+  gtk_binding_entry_add_signal(binding_set, GDK_BackSpace, 0,
+			       "move_cursor", 3,
+			       G_TYPE_ENUM, GTK_MOVEMENT_PAGES,
+			       G_TYPE_INT, -1,
+			       G_TYPE_BOOLEAN, FALSE);
+
   klass->link_mouse_over = NULL;
   klass->link_mouse_out = NULL;
   klass->link_mouse_press = NULL;
@@ -378,29 +389,16 @@ trace_free(gpointer pointer)
 static void
 bbs_thread_view_init(BBSThreadView *view)
 {
-  GtkWidget *widget;
+  GtkWidget *widget = GTK_WIDGET(view);
   GtkTextBuffer *buffer = gtk_text_buffer_new(default_tag_table);
 
-  widget = gtk_text_view_new_with_buffer(buffer);
+  gtk_text_view_set_buffer(&view->text_view, buffer);
 
   view->text_buffer = buffer;
-  view->text_view = GTK_TEXT_VIEW(widget);
-  gtk_text_view_set_wrap_mode(view->text_view, GTK_WRAP_CHAR);
-  gtk_text_view_set_editable(view->text_view, FALSE);
-  gtk_text_view_set_cursor_visible(view->text_view, FALSE);
-  gtk_widget_show(widget);
 
-  gtk_scrolled_window_set_policy(&view->text_container,
-				 GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-
-  gtk_scrolled_window_set_hadjustment(&view->text_container, GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 0.0, 0.0, 0.0, 0.0)));
-  gtk_scrolled_window_set_vadjustment(&view->text_container, GTK_ADJUSTMENT(gtk_adjustment_new(0.0, 0.0, 0.0, 0.0, 0.0, 0.0)));
-  /* MEMO: Τ褦GtkAdjustmentͿƤʤassertion˰óݤ:
-   * Gtk-CRITICAL **: file gtkrange.c: line 438 (gtk_range_get_adjustment):
-   * assertion 'GTK_IS_RANGE(range)' failed
-   * 2Ф롣
-   */
-  gtk_container_add(GTK_CONTAINER(&view->text_container), widget);
+  gtk_text_view_set_wrap_mode(&view->text_view, GTK_WRAP_CHAR);
+  gtk_text_view_set_editable(&view->text_view, FALSE);
+  gtk_text_view_set_cursor_visible(&view->text_view, FALSE);
 
   g_signal_connect(G_OBJECT(widget), "realize",
 		   G_CALLBACK(text_view_realize_cb), view);
@@ -415,7 +413,7 @@ bbs_thread_view_init(BBSThreadView *view)
   g_signal_connect(G_OBJECT(widget), "button_release_event",
 		   G_CALLBACK(button_release_event_cb), view);
 
-  gtk_text_buffer_get_start_iter(view->text_buffer, &view->iter);
+  gtk_text_buffer_get_start_iter(buffer, &view->iter);
 
   view->tags = NULL;
 
@@ -423,8 +421,8 @@ bbs_thread_view_init(BBSThreadView *view)
   view->thread = NULL;
   view->link_table = g_hash_table_new_full(NULL, NULL, NULL, TRACE_FREE);
 
-  view->insert_mark = gtk_text_buffer_get_mark(view->text_buffer, "insert");
-  view->selection_bound_mark = gtk_text_buffer_get_mark(view->text_buffer,
+  view->insert_mark = gtk_text_buffer_get_mark(buffer, "insert");
+  view->selection_bound_mark = gtk_text_buffer_get_mark(buffer,
 							"selection_bound");
 }
 
@@ -674,7 +672,7 @@ emit_link_mouse_over(BBSThreadView *view, GdkEventMotion *event)
   if (link == NULL)
     return;
 
-  gdk_window_set_cursor(gtk_text_view_get_window(view->text_view,
+  gdk_window_set_cursor(gtk_text_view_get_window(&view->text_view,
 						 GTK_TEXT_WINDOW_TEXT),
 			view->hand_cursor);
 
@@ -705,7 +703,7 @@ emit_link_mouse_out(BBSThreadView *view, GdkEventAny *event)
   if (link == NULL)
     return;
 
-  gdk_window_set_cursor(gtk_text_view_get_window(view->text_view,
+  gdk_window_set_cursor(gtk_text_view_get_window(&view->text_view,
 						 GTK_TEXT_WINDOW_TEXT),
 			view->ibeam_cursor);
 
@@ -814,24 +812,6 @@ bbs_thread_view_get_thread(BBSThreadView *view)
 }
 
 
-void
-bbs_thread_view_set_wrap_mode(BBSThreadView *view, GtkWrapMode mode)
-{
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view));
-
-  gtk_text_view_set_wrap_mode(view->text_view, mode);
-}
-
-
-GtkWrapMode
-bbs_thread_view_get_wrap_mode(BBSThreadView *view)
-{
-  g_return_val_if_fail(IS_BBS_THREAD_VIEW(view), 0);
-
-  return gtk_text_view_get_wrap_mode(view->text_view);
-}
-
-
 void
 bbs_thread_view_clear(BBSThreadView *view)
 {
@@ -888,7 +868,7 @@ bbs_thread_view_delete_mark(BBSThreadView *view, GtkTextMark *mark)
 
   g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
-  if (view->text_view == NULL || mark == NULL)
+  if (mark == NULL)
     return;
 
   buffer = gtk_text_mark_get_buffer(mark);
@@ -1002,11 +982,7 @@ bbs_thread_view_append_widget(BBSThreadView *view, GtkWidget *widget)
   g_return_if_fail(IS_BBS_THREAD_VIEW(view) && GTK_IS_WIDGET(widget));
 
   anchor = gtk_text_buffer_create_child_anchor(view->text_buffer, &view->iter);
-  /*
-   * MEMO: gtk_text_view_add_child_at_anchorwidgetref_count䤹褦
-   *       ˸ºݤˤ䤵ʤ餷ġġ
-   */
-  gtk_text_view_add_child_at_anchor(view->text_view, widget, anchor);
+  gtk_text_view_add_child_at_anchor(&view->text_view, widget, anchor);
 }
 
 
@@ -1106,14 +1082,14 @@ bbs_thread_view_scroll_to_start(BBSThreadView *view)
   GtkTextBuffer *buffer;
   gboolean result;
 
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_view != NULL);
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
-  buffer = gtk_text_view_get_buffer(view->text_view);
+  buffer = gtk_text_view_get_buffer(&view->text_view);
   g_return_if_fail(buffer != NULL);
 
   gtk_text_buffer_get_start_iter(buffer, &iter);
   gtk_text_buffer_place_cursor(buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(view->text_view,
+  result = gtk_text_view_scroll_to_iter(&view->text_view,
 					&iter, 0.0, FALSE, 0.0, 0.0);
 }
 
@@ -1125,14 +1101,14 @@ bbs_thread_view_scroll_to_end(BBSThreadView *view)
   GtkTextBuffer *buffer;
   gboolean result;
 
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_view != NULL);
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view));
 
-  buffer = gtk_text_view_get_buffer(view->text_view);
+  buffer = gtk_text_view_get_buffer(&view->text_view);
   g_return_if_fail(buffer != NULL);
 
   gtk_text_buffer_get_end_iter(buffer, &iter);
   gtk_text_buffer_place_cursor(buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(view->text_view,
+  result = gtk_text_view_scroll_to_iter(&view->text_view,
 					&iter, 0.0, FALSE, 0.0, 0.0);
 }
 
@@ -1144,17 +1120,17 @@ bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset)
   gint previous_offset;
   gboolean result;
 
-  g_return_val_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_view != NULL
-		       && view->text_buffer != NULL, 0);
+  g_return_val_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_buffer != NULL,
+		       0);
 
-  gtk_text_view_place_cursor_onscreen(view->text_view);
+  gtk_text_view_place_cursor_onscreen(&view->text_view);
   gtk_text_buffer_get_iter_at_mark(view->text_buffer, &iter,
 				   gtk_text_buffer_get_insert(view->text_buffer));
   previous_offset = gtk_text_iter_get_offset(&iter);
 
   gtk_text_buffer_get_iter_at_offset(view->text_buffer, &iter, offset);
   gtk_text_buffer_place_cursor(view->text_buffer, &iter);
-  result = gtk_text_view_scroll_to_iter(view->text_view,
+  result = gtk_text_view_scroll_to_iter(&view->text_view,
 					&iter, 0.0, FALSE, 0.0, 0.0);
 
   return previous_offset;
@@ -1167,8 +1143,7 @@ bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark)
   GtkTextIter iter;
   GtkTextBuffer *buffer;
 
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view)
-		   && view->text_view != NULL && mark != NULL);
+  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && mark != NULL);
 
   buffer = gtk_text_mark_get_buffer(mark);
   g_return_if_fail(buffer != NULL);
@@ -1177,32 +1152,13 @@ bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark)
   gtk_text_buffer_place_cursor(buffer, &iter);
 
 #if 0	/* XXX: ɤäʡ */
-  gtk_text_view_scroll_to_mark(view->text_view, mark, 0.3, FALSE, 0.5, 0.5);
+  gtk_text_view_scroll_to_mark(&view->text_view, mark, 0.3, FALSE, 0.5, 0.5);
 #else
-  gtk_text_view_scroll_to_mark(view->text_view, mark, 0.3, TRUE, 0.5, 0.5);
+  gtk_text_view_scroll_to_mark(&view->text_view, mark, 0.3, TRUE, 0.5, 0.5);
 #endif
 }
 
 
-void
-bbs_thread_view_place_cursor_onscreen(BBSThreadView *view)
-{
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view) && view->text_view != NULL);
-
-  gtk_text_view_place_cursor_onscreen(view->text_view);
-}
-
-
-void
-bbs_thread_view_hide_scrollbar(BBSThreadView *view)
-{
-  g_return_if_fail(IS_BBS_THREAD_VIEW(view));
-
-  gtk_scrolled_window_set_policy(&view->text_container,
-				 GTK_POLICY_NEVER, GTK_POLICY_NEVER);
-}
-
-
 /* Ϣ */
 static void
 bbs_thread_view_scroll_to_offsets(BBSThreadView *view,
@@ -1217,9 +1173,9 @@ bbs_thread_view_scroll_to_offsets(BBSThreadView *view,
 				     + end_offset);
   gtk_text_buffer_move_mark(view->text_buffer, view->selection_bound_mark,
 			    &iter);
-  gtk_text_view_scroll_mark_onscreen(view->text_view,
+  gtk_text_view_scroll_mark_onscreen(&view->text_view,
 				     view->insert_mark);
-  gtk_text_view_scroll_mark_onscreen(view->text_view,
+  gtk_text_view_scroll_mark_onscreen(&view->text_view,
 				     view->selection_bound_mark);
 }
 
