@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bbs_thread_view.h,v 1.6 2003/06/12 02:02:08 fuyu Exp $
+ * $Id: bbs_thread_view.h,v 1.8 2003/11/05 10:22:15 fuyu Exp $
  */
 
 #ifndef _BBS_THREAD_VIEW_H_
@@ -66,9 +66,8 @@ typedef enum {
 
 struct _BBSThreadView
 {
-  GtkScrolledWindow text_container;
+  GtkTextView text_view;
 
-  GtkTextView *text_view;
   GtkTextBuffer *text_buffer;
 
   GdkCursor *ibeam_cursor;
@@ -108,7 +107,7 @@ struct _BBSThreadView
 
 struct _BBSThreadViewClass
 {
-  GtkScrolledWindowClass parent_class;
+  GtkTextViewClass parent_class;
 
   GtkTextTagTable *tag_table;
 
@@ -131,14 +130,11 @@ struct _BBSThreadViewClass
 			    GdkEventCrossing *event);
 
   void (*scroll_to)(BBSThreadView *bbs_thread_view, gint to_where);
+  void (*move_cursor)(BBSThreadView *bbs_thread_view, GtkMovementStep step,
+		      gint count, gboolean extend_selection);
 };
 
 
-typedef struct _BBSThreadInfo
-{
-} BBSThreadInfo;
-
-
 GType bbs_thread_view_get_type(void);
 
 GtkTextTagTable *bbs_thread_view_class_get_default_tag_table(BBSThreadViewClass *klass);
@@ -147,9 +143,6 @@ GtkWidget *bbs_thread_view_new(OchushaBBSThread *thread);
 void bbs_thread_view_set_thread(BBSThreadView *view, OchushaBBSThread *thread);
 OchushaBBSThread *bbs_thread_view_get_thread(BBSThreadView *view);
 
-void bbs_thread_view_set_wrap_mode(BBSThreadView *view, GtkWrapMode mode);
-GtkWrapMode bbs_thread_view_get_wrap_mode(BBSThreadView *view);
-
 void bbs_thread_view_clear(BBSThreadView *view);
 
 gint bbs_thread_view_get_current_offset(BBSThreadView *view);
@@ -178,10 +171,6 @@ void bbs_thread_view_scroll_to_end(BBSThreadView *view);
 void bbs_thread_view_scroll_to_mark(BBSThreadView *view, GtkTextMark *mark);
 gint bbs_thread_view_scroll_to_offset(BBSThreadView *view, gint offset);
 
-void bbs_thread_view_place_cursor_onscreen(BBSThreadView *view);
-
-void bbs_thread_view_hide_scrollbar(BBSThreadView *view);
-
 gboolean bbs_thread_view_find(BBSThreadView *view, const gchar *key,
 			      BBSThreadViewSearchDirection direction,
 			      gboolean enable_wrap, gboolean match_case,
