@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_ui.c,v 1.18 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: boardlist_ui.c,v 1.19 2003/11/05 11:00:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -50,6 +50,7 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 
 
 #if DEBUG_WIDGET_MOST
@@ -452,6 +453,7 @@ refresh_threadlist_helper(gpointer data, gpointer user_data)
   OchushaBulletinBoard *board = (OchushaBulletinBoard *)data;
   OchushaApplication *application = (OchushaApplication *)user_data;
   refresh_threadlist_view(application, board);
+  sleep(1);
 }
 
 
