@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: boardlist_view.c,v 1.8 2003/06/21 14:52:21 fuyu Exp $
+ * $Id: boardlist_view.c,v 1.9 2003/06/21 19:20:16 fuyu Exp $
  */
 
 #include "config.h"
@@ -623,6 +623,20 @@ boardlist_view_move_cursor(BoardlistView *view, GtkMovementStep step,
 }
 
 
+enum {
+  BOARDLIST_ROW_STATE_HIDDEN = 1,
+  BOARDLIST_ROW_STATE_KILLED = 1 << 1,
+};
+
+
+static guint
+encode_row_state(gboolean hidden, gboolean killed)
+{
+  return (hidden ? BOARDLIST_ROW_STATE_HIDDEN : 0)
+    | (killed ? BOARDLIST_ROW_STATE_KILLED : 0);
+}
+
+
 typedef struct _DoOnSelectionArgs
 {
   BoardlistView *view;
@@ -662,39 +676,57 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
     case POPUP_MENU_TOGGLE_HIDE_SELECTION:
       if (OCHUSHA_IS_BOARD_CATEGORY(data))
 	{
+	  OchushaBoardCategory *category = OCHUSHA_BOARD_CATEGORY(data);
 	  g_signal_emit(G_OBJECT(args->view),
 			boardlist_view_signals[TOGGLE_HIDE_CATEGORY_SIGNAL],
 			0,
-			data);
+			category);
 	  gtk_tree_store_set(GTK_TREE_STORE(model), iter,
 			     BOARDLIST_ROW_STATE,
-			     OCHUSHA_BOARD_CATEGORY(data)->hidden,
+			     encode_row_state(category->hidden,
+					      category->killed),
 			     -1);
 	}
       else if (OCHUSHA_IS_BULLETIN_BOARD(data))
 	{
+	  OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(data);
 	  g_signal_emit(G_OBJECT(args->view),
 			boardlist_view_signals[TOGGLE_HIDE_BOARD_SIGNAL],
 			0,
-			data);
+			board);
 	  gtk_tree_store_set(GTK_TREE_STORE(model), iter,
 			     BOARDLIST_ROW_STATE,
-			     OCHUSHA_BULLETIN_BOARD(data)->hidden,
+			     encode_row_state(board->hidden, board->killed),
 			     -1);
 	}
       break;
 
     case POPUP_MENU_KILL_SELECTION:
       if (OCHUSHA_IS_BOARD_CATEGORY(data))
-	g_signal_emit(G_OBJECT(args->view),
-		      boardlist_view_signals[KILL_CATEGORY_SIGNAL],
-		      0,
-		      data);
+	{
+	  OchushaBoardCategory *category = OCHUSHA_BOARD_CATEGORY(data);
+	  g_signal_emit(G_OBJECT(args->view),
+			boardlist_view_signals[KILL_CATEGORY_SIGNAL],
+			0,
+			category);
+	  gtk_tree_store_set(GTK_TREE_STORE(model), iter,
+			     BOARDLIST_ROW_STATE,
+			     encode_row_state(category->hidden,
+					      category->killed),
+			     -1);
+	}
       else if (OCHUSHA_IS_BULLETIN_BOARD(data))
-	g_signal_emit(G_OBJECT(args->view),
-		      boardlist_view_signals[KILL_BOARD_SIGNAL],
-		      0,
-		      data);
+	{
+	  OchushaBulletinBoard *board = OCHUSHA_BULLETIN_BOARD(data);
+	  g_signal_emit(G_OBJECT(args->view),
+			boardlist_view_signals[KILL_BOARD_SIGNAL],
+			0,
+			board);
+	  gtk_tree_store_set(GTK_TREE_STORE(model), iter,
+			     BOARDLIST_ROW_STATE,
+			     encode_row_state(board->hidden, board->killed),
+			     -1);
+	}
       break;
     }
 }
@@ -980,16 +1012,16 @@ decorate_boardlist_entry(GtkTreeViewColumn *tree_column,
 			 GtkCellRenderer *renderer, GtkTreeModel *tree_model,
 			 GtkTreeIter *iter, gpointer view)
 {
-  guint hidden;
+  guint state;
   g_return_if_fail(gtk_tree_store_iter_is_valid(GTK_TREE_STORE(tree_model),
 						iter));
   gtk_tree_model_get(tree_model, iter,
-		     BOARDLIST_ROW_STATE, &hidden, -1);
+		     BOARDLIST_ROW_STATE, &state, -1);
 
   if (!GTK_IS_CELL_RENDERER_TEXT(renderer))
     return;
 
-  if (hidden)
+  if ((state & BOARDLIST_ROW_STATE_HIDDEN) != 0)
     {
       GValue st = { 0, };
       GValue fg = { 0, };
@@ -1015,6 +1047,14 @@ decorate_boardlist_entry(GtkTreeViewColumn *tree_column,
       g_value_set_static_string(&fg, NULL);
       g_object_set_property((GObject *)renderer, "foreground", &fg);
     }
+
+  if ((state & BOARDLIST_ROW_STATE_KILLED) != 0)
+    {
+      GValue fg = { 0, };
+      g_value_init(&fg, G_TYPE_STRING);
+      g_value_set_static_string(&fg, "white");
+      g_object_set_property((GObject *)renderer, "foreground", &fg);
+    }
 }
 
 
@@ -1040,7 +1080,8 @@ append_board(gpointer data, gpointer user_data)
   gtk_tree_store_set(args->store, &info->iter,
 		     BOARDLIST_LABEL, board->name,
 		     BOARDLIST_ROW_TYPE, BOARDLIST_BOARD_ROW,
-		     BOARDLIST_ROW_STATE, board->hidden,
+		     BOARDLIST_ROW_STATE, encode_row_state(board->hidden,
+							   board->killed),
 		     BOARDLIST_DATA, board,
 		     -1);
 }
@@ -1061,7 +1102,8 @@ append_category(gpointer data, gpointer user_data)
   gtk_tree_store_set(args->store, args->category_iter,
 		     BOARDLIST_LABEL, category->name,
 		     BOARDLIST_ROW_TYPE, BOARDLIST_CATEGORY_ROW,
-		     BOARDLIST_ROW_STATE, category->hidden,
+		     BOARDLIST_ROW_STATE, encode_row_state(category->hidden,
+							   category->killed),
 		     BOARDLIST_DATA, category,
 		     -1);
 
