@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.c,v 1.32 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: bulletin_board_ui.c,v 1.39 2003/11/05 11:00:17 fuyu Exp $
  */
 
 #include "config.h"
@@ -68,6 +68,8 @@ static void toggle_mark_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
 static void toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   OchushaApplication *application);
+static void copy_thread_url_cb(ThreadlistView *view, OchushaBBSThread *thread,
+			       OchushaApplication *application);
 static void mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread,
 			   gboolean do_mark, OchushaApplication *application);
 static void thread_mouse_over_cb(ThreadlistView *view,
@@ -565,6 +567,8 @@ open_bulletin_board(OchushaApplication *application,
 		       G_CALLBACK(toggle_mark_cb), application);
       g_signal_connect(G_OBJECT(view), "toggle_hide",
 		       G_CALLBACK(toggle_hide_cb), application);
+      g_signal_connect(G_OBJECT(view), "copy_thread_url",
+		       G_CALLBACK(copy_thread_url_cb), application);
       g_signal_connect(G_OBJECT(view), "mark_thread",
 		       G_CALLBACK(mark_thread_cb), application);
       g_signal_connect(G_OBJECT(view), "thread_mouse_over",
@@ -1140,6 +1144,14 @@ toggle_hide_cb(ThreadlistView *view, OchushaBBSThread *thread,
 }
 
 
+static void
+copy_thread_url_cb(ThreadlistView *view, OchushaBBSThread *thread,
+	       OchushaApplication *application)
+{
+  ochusha_clipboard_set_text(application, ochusha_bbs_thread_get_url(thread));
+}
+
+
 static void
 mark_thread_cb(ThreadlistView *view, OchushaBBSThread *thread, gboolean do_mark,
 	       OchushaApplication *application)
@@ -1213,7 +1225,7 @@ thread_title_popup_timeout(gpointer data)
   if (data == popup_thread)
     {
       THREAD_LIST_LOCK
-	{
+        {
 	  thread_title_popup_show();
 
 	  if (title_popup_delay_id != 0)
@@ -1269,10 +1281,31 @@ item_view_required_cb(PanedNotebook *paned_notebook,
 		      const gchar **title, GtkWidget **tab_label,
 		      OchushaApplication *application)
 {
+#if 1
+  GtkWidget *thread_view;
   *tab_label = get_tab_label(thread->title);
-  *item_view = open_bbs_thread(application, thread, ICON_LABEL(*tab_label));
-  gtk_widget_show(*item_view);
+
+  thread_view = open_bbs_thread(application, thread, ICON_LABEL(*tab_label));
+  if (thread_view != NULL)
+    {
+      gtk_widget_show(thread_view);
+      *item_view = gtk_scrolled_window_new(NULL, NULL);
+      gtk_container_add(GTK_CONTAINER(*item_view), thread_view);
+      gtk_widget_show(*item_view);
+    }
+  else
+    *item_view = NULL;
+
   *title = thread->title;
+#else
+  *tab_label = get_tab_label(thread->title);
+
+  *item_view = open_bbs_thread(application, thread, ICON_LABEL(*tab_label));
+  if (*item_view != NULL)
+    gtk_widget_show(*item_view);
+
+  *title = thread->title;
+#endif
 }
 
 
@@ -1297,8 +1330,8 @@ free_response_source_buffer(OchushaBBSThread *thread, gpointer unused)
 
 
 static void
-item_view_being_closed_cb(PanedNotebook *paned_notebook, OchushaBBSThread *thread,
-			  GtkWidget *item_view,
+item_view_being_closed_cb(PanedNotebook *paned_notebook,
+			  OchushaBBSThread *thread, GtkWidget *item_view,
 			  OchushaApplication *application)
 {
   BBSThreadGUIInfo *info;
@@ -1416,9 +1449,11 @@ page_switched_cb(PanedNotebook *paned_notebook,
    */
   if (previous_page != NULL)
     {
+      GtkTextView *thread_view
+	= GTK_TEXT_VIEW(gtk_bin_get_child(GTK_BIN(previous_page)));
       thread = (OchushaBBSThread *)paned_notebook_get_item(paned_notebook,
 						    previous_page);
-      bbs_thread_view_place_cursor_onscreen(BBS_THREAD_VIEW(previous_page));
+      gtk_text_view_place_cursor_onscreen(thread_view);
       if (thread != NULL)
 	{
 	  info = ensure_bbs_thread_info(thread);
@@ -1435,7 +1470,7 @@ page_switched_cb(PanedNotebook *paned_notebook,
     else
       {
 	snprintf(pseudo_url, PATH_MAX, "http://%s/%s",
-		 thread->board->server, thread->pseudo_path);
+		 thread->board->server, ochusha_bbs_thread_get_url(thread));
 	set_current_url(application, pseudo_url);
       }
   }
@@ -1449,7 +1484,11 @@ page_switched_cb(PanedNotebook *paned_notebook,
 
   info = ensure_bbs_thread_info(thread);
   if (info->next_mark != NULL)
-    bbs_thread_view_scroll_to_mark(BBS_THREAD_VIEW(new_page), info->next_mark);
+    {
+      BBSThreadView *thread_view
+	= BBS_THREAD_VIEW(gtk_bin_get_child(GTK_BIN(new_page)));
+      bbs_thread_view_scroll_to_mark(thread_view, info->next_mark);
+    }
 
   if (application->show_threadlist_entry_when_thread_selected)
     threadlist_view_scroll_to_thread(threadlist_view, thread);
@@ -1476,7 +1515,10 @@ get_current_thread(OchushaApplication *application,
     }
 
   if (view != NULL)
-    *view = paned_notebook_get_current_item_view(paned_notebook);
+    {
+      GtkWidget *bin = paned_notebook_get_current_item_view(paned_notebook);
+      *view = gtk_bin_get_child(GTK_BIN(bin));
+    }
   if (thread != NULL)
     *thread = (OchushaBBSThread *)paned_notebook_get_current_item(paned_notebook);
   if (tab_label != NULL)
@@ -1523,24 +1565,14 @@ reverse_strpbrk(const gchar *string, const gchar *charset)
 }
 
 
-void
-write_response(OchushaApplication *application)
+static void
+write_dialog_response_cb(GtkWidget *write_dialog, gint response_id,
+			 OchushaApplication *application)
 {
-  GtkWidget *view;
-  OchushaBBSThread *thread;
-  IconLabel *tab_label;
-  GtkWidget *write_dialog;
-  int response_id;
+  OchushaBBSThread *thread = g_object_get_data(G_OBJECT(write_dialog),
+					       "thread");
   gboolean result;
 
-  get_current_thread(application, &view, &thread, &tab_label);
-  if (view == NULL || thread == NULL)
-    return;
-
-  write_dialog = create_write_dialog(application, thread);
-
-  response_id = gtk_dialog_run(GTK_DIALOG(write_dialog));
-
   if (response_id == GTK_RESPONSE_OK)
     {
       ResponseEditor *editor = g_object_get_data(G_OBJECT(write_dialog),
@@ -1634,7 +1666,20 @@ write_response(OchushaApplication *application)
   if (result)
     {
       if (response_id == GTK_RESPONSE_OK)
-	refresh_current_thread(application);
+	{
+	  GtkWidget *notebook = paned_notebook_get_item_view(PANED_NOTEBOOK(application->contents_window), thread->board);
+	  if (notebook != NULL)
+	    {
+	      GtkWidget *view = paned_notebook_get_item_view(PANED_NOTEBOOK(notebook), thread);
+	      GtkWidget *label = paned_notebook_get_tab_label(PANED_NOTEBOOK(notebook), thread);
+	      if (view != NULL && label != NULL)
+		{
+		  GtkWidget *thread_view = gtk_bin_get_child(GTK_BIN(view));
+		  refresh_thread(application, thread_view, thread,
+				 ICON_LABEL(label));
+		}
+	    }
+	}
     }
   else
     ochusha_open_url(application,
@@ -1643,6 +1688,39 @@ write_response(OchushaApplication *application)
 }
 
 
+void
+write_response(OchushaApplication *application)
+{
+  BBSThreadGUIInfo *info;
+  GtkWidget *view;
+  OchushaBBSThread *thread;
+  IconLabel *tab_label;
+  GtkWidget *write_dialog;
+
+  get_current_thread(application, &view, &thread, &tab_label);
+  if (view == NULL || thread == NULL)
+    return;
+
+  info = ensure_bbs_thread_info(thread);
+
+  if (info->write_dialog == NULL)
+    {
+      write_dialog = create_write_dialog(application, thread);
+      info->write_dialog = write_dialog;
+    }
+  else
+    return;
+
+  g_signal_connect(G_OBJECT(write_dialog), "response",
+		   G_CALLBACK(write_dialog_response_cb), application);
+  g_signal_connect(G_OBJECT(write_dialog), "destroy",
+		   G_CALLBACK(gtk_widget_destroyed),
+		   &info->write_dialog);
+
+  gtk_widget_show_all(write_dialog);
+}
+
+
 void
 refresh_current_thread(OchushaApplication *application)
 {
@@ -1850,6 +1928,11 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
 {
   GtkWidget *write_dialog;
   GtkWidget *dialog_vbox;
+  GtkWidget *url_hbox;
+  GtkWidget *url_entry;
+  GtkWidget *title_hbox;
+  GtkWidget *title_label;
+  GtkWidget *board_label;
   GtkWidget *editor;
   ResponseEditor *response_editor;
   BBSThreadGUIInfo *thread_info = ensure_bbs_thread_info(thread);
@@ -1859,15 +1942,45 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
   gboolean has_mail = FALSE;
 
   write_dialog = gtk_dialog_new_with_buttons(_("Write a response"),
-			application->top_level,
-			GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-			GTK_STOCK_OK, GTK_RESPONSE_OK,
-			NULL);
+					 application->top_level,
+					 GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+					 GTK_STOCK_OK, GTK_RESPONSE_OK,
+					 NULL);
   gtk_window_set_position(GTK_WINDOW(write_dialog), GTK_WIN_POS_CENTER);
   gtk_window_set_default_size(GTK_WINDOW(write_dialog), -1, 250);
 
   dialog_vbox = GTK_DIALOG(write_dialog)->vbox;
+
+  title_hbox = gtk_hbox_new(FALSE, 5);
+  title_label = gtk_label_new(ochusha_bbs_thread_get_title(thread));
+  gtk_label_set_justify(GTK_LABEL(title_label), GTK_JUSTIFY_RIGHT);
+  gtk_box_pack_start(GTK_BOX(title_hbox), title_label, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(title_hbox),
+		     gtk_label_new(_("@")), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(title_hbox),
+		gtk_label_new(ochusha_bulletin_board_get_name(thread->board)),
+		FALSE, FALSE, 0);
+  board_label = gtk_label_new(_("board"));
+  gtk_label_set_justify(GTK_LABEL(board_label), GTK_JUSTIFY_LEFT);
+  gtk_box_pack_start(GTK_BOX(title_hbox), board_label, FALSE, FALSE, 5);
+
+  gtk_widget_show_all(title_hbox);
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), title_hbox, FALSE, FALSE, 0);
+
+
+  url_hbox = gtk_hbox_new(FALSE, 5);
+  gtk_box_pack_start(GTK_BOX(url_hbox), gtk_label_new("URL: "),
+		     FALSE, FALSE, 0);
+  url_entry = gtk_entry_new();
+  gtk_entry_set_text(GTK_ENTRY(url_entry), ochusha_bbs_thread_get_url(thread));
+  gtk_editable_set_editable(GTK_EDITABLE(url_entry), FALSE);
+  GTK_WIDGET_UNSET_FLAGS(url_entry, GTK_CAN_FOCUS);
+  gtk_box_pack_start(GTK_BOX(url_hbox), url_entry, TRUE, TRUE, 0);
+  gtk_widget_show_all(url_hbox);
+  gtk_box_pack_start(GTK_BOX(dialog_vbox), url_hbox, FALSE, FALSE, 0);
+
+
   editor = response_editor_new(thread);
   response_editor = RESPONSE_EDITOR(editor);
 
@@ -1924,8 +2037,7 @@ create_write_dialog(OchushaApplication *application, OchushaBBSThread *thread)
   gtk_box_pack_start(GTK_BOX(dialog_vbox), editor, TRUE, TRUE, 0);
 
   g_object_set_data(G_OBJECT(write_dialog), "editor", editor);
-
-  gtk_widget_show_all(write_dialog);
+  g_object_set_data(G_OBJECT(write_dialog), "thread", thread);
 
   return write_dialog;
 }
