@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: bulletin_board_ui.h,v 1.9 2003/06/20 18:14:40 fuyu Exp $
+ * $Id: bulletin_board_ui.h,v 1.10 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #ifndef _BULLETIN_BOARD_UI_H_
@@ -52,6 +52,12 @@ typedef struct _BulletinBoardGUIInfo
 
   GtkWidget *properties_dialog;
 
+  /* Ǹν񤭹߻̾ */
+  gchar *last_name;
+
+  /* Ǹν񤭹߻Υᥤ */
+  gchar *last_mail;
+
   ThreadlistFilter filter;
 
   gboolean enable_filter;
