@@ -246,7 +246,46 @@ ochusha_marshal_VOID__BOXED_POINTER_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:12) */
+/* VOID:ENUM,INT,BOOLEAN (marshal.list:12) */
+void
+ochusha_marshal_VOID__ENUM_INT_BOOLEAN (GClosure     *closure,
+                                        GValue       *return_value,
+                                        guint         n_param_values,
+                                        const GValue *param_values,
+                                        gpointer      invocation_hint,
+                                        gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (gpointer     data1,
+                                                       gint         arg_1,
+                                                       gint         arg_2,
+                                                       gboolean     arg_3,
+                                                       gpointer     data2);
+  register GMarshalFunc_VOID__ENUM_INT_BOOLEAN callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__ENUM_INT_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_enum (param_values + 1),
+            g_marshal_value_peek_int (param_values + 2),
+            g_marshal_value_peek_boolean (param_values + 3),
+            data2);
+}
+
+/* VOID:POINTER,POINTER,POINTER,POINTER (marshal.list:13) */
 void
 ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
                                                        GValue       *return_value,
@@ -287,7 +326,7 @@ ochusha_marshal_VOID__POINTER_POINTER_POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* BOOLEAN:ENUM,INT (marshal.list:13) */
+/* BOOLEAN:ENUM,INT (marshal.list:14) */
 void
 ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
                                    GValue       *return_value,
@@ -328,7 +367,7 @@ ochusha_marshal_BOOLEAN__ENUM_INT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (marshal.list:14) */
+/* BOOLEAN:OBJECT (marshal.list:15) */
 void
 ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                  GValue       *return_value,
@@ -367,7 +406,7 @@ ochusha_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:15) */
+/* BOOLEAN:BOXED,POINTER,STRING (marshal.list:16) */
 void
 ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
                                                GValue       *return_value,
@@ -410,7 +449,7 @@ ochusha_marshal_BOOLEAN__BOXED_POINTER_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:16) */
+/* BOOLEAN:STRING,INT,BOOLEAN,BOOLEAN,BOOLEAN (marshal.list:17) */
 void
 ochusha_marshal_BOOLEAN__STRING_INT_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
                                                              GValue       *return_value,
