@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_ui.h,v 1.15 2003/06/21 16:23:53 fuyu Exp $
+ * $Id: ochusha_ui.h,v 1.16 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UI_H_
@@ -226,6 +226,12 @@ struct _OchushaApplication
 
   OchushaNetworkBroker *broker;
 
+  /* Ǹν񤭹߻̾ */
+  gchar *last_name;
+
+  /* Ǹν񤭹߻Υᥤ */
+  gchar *last_mail;
+
   OchushaConfig config;
 };
 
