@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: response_editor.c,v 1.3 2003/11/04 07:59:09 fuyu Exp $
+ * $Id: response_editor.c,v 1.4 2003/11/04 11:38:45 fuyu Exp $
  */
 
 #include "config.h"
@@ -114,7 +114,7 @@ response_editor_init(ResponseEditor *editor)
   hbox = gtk_hbox_new(FALSE, 5);
   editor->hbox = GTK_BOX(hbox);
   gtk_widget_show(hbox);
-  gtk_box_pack_start(GTK_BOX(&editor->container), hbox, TRUE, TRUE, 0);
+  gtk_box_pack_start(GTK_BOX(&editor->container), hbox, FALSE, FALSE, 0);
 
   name_label = gtk_label_new(_("Name:"));
   gtk_widget_show(name_label);
