@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: response_editor.h,v 1.1 2003/06/27 08:35:50 fuyu Exp $
+ * $Id: response_editor.h,v 1.3 2003/11/04 07:59:09 fuyu Exp $
  */
 
 #ifndef _RESPONSE_EDITOR_H_
@@ -54,11 +54,17 @@ struct _ResponseEditor
 {
   GtkVBox container;
 
-  /* vboxȤtoolbartext_view */
-  GtkToolbar *toolbar;
+  /* containerȤhboxtext_view */
+  GtkBox *hbox;
+
+  /* hboxȤname_combomail_comboȤդ٥ */
+  GtkCombo *name_combo;
+  GtkCombo *mail_combo;
 
   GtkTextView *text_view;
-  GtkTextBuffer *text_buffer;
+
+  GList *name_list;
+  GList *mail_list;
 
   OchushaBBSThread *thread;
 };
@@ -74,6 +80,20 @@ GType response_editor_get_type(void);
 
 GtkWidget *response_editor_new(OchushaBBSThread *thread);
 
+const gchar *response_editor_get_name(ResponseEditor *editor);
+void response_editor_set_name(ResponseEditor *editor, const gchar *name);
+void response_editor_add_name(ResponseEditor *editor, const gchar *name);
+
+const gchar *response_editor_get_mail(ResponseEditor *editor);
+void response_editor_set_mail(ResponseEditor *editor, const gchar *mail);
+void response_editor_add_mail(ResponseEditor *editor, const gchar *name);
+
+gchar *response_editor_get_response(ResponseEditor *editor);
+#if 0
+void response_editor_set_response(ResponseEditor *editor,
+				  const gchar *response);
+#endif
+
 
 #ifdef __cplusplus
 } // extern "C"
