@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.c,v 1.16 2003/06/21 16:23:53 fuyu Exp $
+ * $Id: threadlist_view.c,v 1.17 2003/11/05 07:54:50 fuyu Exp $
  */
 
 #include "config.h"
@@ -138,6 +138,7 @@ enum {
   TOGGLE_MARK_SIGNAL,
   TOGGLE_HIDE_SIGNAL,
   MARK_THREAD_SIGNAL,
+  COPY_THREAD_URL_SIGNAL,
   ADVANCE_VIEW_SIGNAL,
   BACK_VIEW_SIGNAL,
 
@@ -174,7 +175,8 @@ enum {
   POPUP_MENU_OPEN_SELECTION_IN_TAB,
   POPUP_MENU_MARK_SELECTION,
   POPUP_MENU_UNMARK_SELECTION,
-  POPUP_MENU_TOGGLE_HIDE_SELECTION
+  POPUP_MENU_TOGGLE_HIDE_SELECTION,
+  POPUP_MENU_COPY_THREAD_URL
 };
 
 
@@ -187,7 +189,7 @@ struct _ThreadlistInfo
 
 static GtkScrolledWindowClass *parent_class = NULL;
 static gint threadlist_view_signals[LAST_SIGNAL] =
-  { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
+  { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 };
 static gint tree_view_signals[TREE_VIEW_LAST_SIGNAL] = { 0, 0, 0, 0 };
 static GtkItemFactory *popup_menu_item_factory = NULL;
 static GQuark list_entry_info_id;
@@ -287,6 +289,20 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 	POPUP_MENU_TOGGLE_HIDE_SELECTION,	/* act */
 	NULL					/* type */
       },
+      {
+	_("/-------"),
+	NULL,
+	NULL,
+	0,
+	"<Separator>"
+      },
+      {
+	_("/Copy Selected Thread's URL"),	/* menu path */
+	NULL,					/* accelerator */
+	popup_menu_callback,			/* callback_func */
+	POPUP_MENU_COPY_THREAD_URL,		/* act */
+	NULL					/* type */
+      },
     };
   gint nmenu_items = sizeof(menu_items) / sizeof(menu_items[0]);
 
@@ -354,6 +370,16 @@ threadlist_view_class_init(ThreadlistViewClass *klass)
 		 ochusha_marshal_VOID__POINTER,
 		 G_TYPE_NONE, 1,
 		 G_TYPE_POINTER);
+  /* ɥۥå᤮*/
+  threadlist_view_signals[COPY_THREAD_URL_SIGNAL] =
+    g_signal_new("copy_thread_url",
+		 G_TYPE_FROM_CLASS(klass),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET(ThreadlistViewClass, copy_thread_url),
+		 NULL, NULL,
+		 ochusha_marshal_VOID__POINTER,
+		 G_TYPE_NONE, 1,
+		 G_TYPE_POINTER);
   threadlist_view_signals[MARK_THREAD_SIGNAL] =
     g_signal_new("mark_thread",
 		 G_TYPE_FROM_CLASS(klass),
@@ -1107,11 +1133,18 @@ do_on_selection_helper(GtkTreeModel *model, GtkTreePath *path,
 	  break;
 
     case POPUP_MENU_TOGGLE_HIDE_SELECTION:
-	  g_signal_emit(G_OBJECT(args->view),
-			threadlist_view_signals[TOGGLE_HIDE_SIGNAL],
-			0,
-			thread);
-	  break;
+      g_signal_emit(G_OBJECT(args->view),
+		    threadlist_view_signals[TOGGLE_HIDE_SIGNAL],
+		    0,
+		    thread);
+      break;
+
+    case POPUP_MENU_COPY_THREAD_URL:
+      g_signal_emit(G_OBJECT(args->view),
+		    threadlist_view_signals[COPY_THREAD_URL_SIGNAL],
+		    0,
+		    thread);
+      break;
     }
 
 }
