@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: threadlist_view.h,v 1.7 2003/06/21 16:23:53 fuyu Exp $
+ * $Id: threadlist_view.h,v 1.8 2003/11/05 07:54:50 fuyu Exp $
  */
 
 #ifndef _THREADLIST_VIEW_H_
@@ -119,6 +119,8 @@ struct _ThreadlistViewClass
 		      OchushaBBSThread *thread);
   void (*mark_thread)(ThreadlistView *threadlist_view,
 		      OchushaBBSThread *thread, gboolean do_mark);
+  void (*copy_thread_url)(ThreadlistView *threadlist_view,
+			  OchushaBBSThread *thread);
   gboolean (*advance_view)(ThreadlistView *threadlist_view,
 			   OchushaBBSThread *thread);
   gboolean (*back_view)(ThreadlistView *threadlist_view,
