@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ugly_gtk2utils.c,v 1.4 2003/06/07 14:35:31 fuyu Exp $
+ * $Id: ugly_gtk2utils.c,v 1.7 2003/11/05 10:22:15 fuyu Exp $
  */
 
 #include "ugly_gtk2utils.h"
@@ -51,15 +51,6 @@ ugly_gtk_tree_view_unbind_keys(void)
   gtk_binding_entry_remove(binding_set, GDK_n, GDK_CONTROL_MASK);
 
   g_type_class_unref(klass);
-
-  klass = g_type_class_ref(GTK_TYPE_TEXT_VIEW);
-  binding_set = gtk_binding_set_by_class(klass);
-  gtk_binding_entry_remove(binding_set, GDK_End, GDK_CONTROL_MASK);
-  gtk_binding_entry_remove(binding_set, GDK_KP_End, GDK_CONTROL_MASK);
-  gtk_binding_entry_remove(binding_set, GDK_Home, GDK_CONTROL_MASK);
-  gtk_binding_entry_remove(binding_set, GDK_KP_Home, GDK_CONTROL_MASK);
-
-  g_type_class_unref(klass);
 }
 
 
