@@ -23,12 +23,14 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: htmlutils.h,v 1.1.1.1 2003/05/10 16:34:27 fuyu Exp $
+ * $Id: htmlutils.h,v 1.2 2003/07/13 14:53:51 fuyu Exp $
  */
 
 #ifndef _HTMLUTILS_H_
 #define _HTMLUTILS_H_
 
+#include "utils.h"
+
 #include <glib.h>
 #include <iconv.h>
 
@@ -42,6 +44,7 @@ extern "C" {
 typedef struct _ElementHandler
 {
   iconv_t converter;
+  iconv_helper *helper;
 
   void (*startElement)(void *context, const char *name,
 		       const char *const attrs[]);
@@ -55,7 +58,8 @@ void initialize_default_entity_dictionary();
 GHashTable *get_default_entity_dictionary();
 const char *parse_text(ElementHandler *handler, void *context,
 		       const char *text, int len);
-gchar *simple_string_canon(const char *src, int len, iconv_t converter);
+gchar *simple_string_canon(const char *src, int len,
+			   iconv_t converter, iconv_helper *helper);
 
 #ifdef __cplusplus
 } // extern "C"
