@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha.h,v 1.1.1.1 2003/05/10 16:34:28 fuyu Exp $
+ * $Id: ochusha.h,v 1.3 2003/05/25 08:46:15 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_H_
@@ -31,9 +31,6 @@
 
 #include "config.h"
 
-#include "ochusha_async_buffer.h"
-#include "utils.h"
-
 #include <glib.h>
 #include <iconv.h>
 
@@ -49,10 +46,12 @@ extern "C" {
 
 #define OCHUSHA_USER_AGENT		"Monazilla/1.00 (Ochusha/" VERSION ")"
 
+/*
+ * ʲĤ2ch˰¸ƤΤǡ̤ξΤ˾
+ * 櫡ġ
+ */
 #define OCHUSHA_DEFAULT_BBSMENU_URL	"http://www.ff.iij4u.or.jp/~ch2/bbsmenu.html"
-
 #define OCHUSHA_SUBJECT_TXT		"subject.txt"
-
 #define MAX_RESPONSE			1024
 
 
@@ -68,10 +67,18 @@ struct _OchushaConfig
   char *home;
 
 
-  /* İμѤURL */
+  /* İμѤURL: 2ch¸ʤΤ;ɤ٤⤷ */
   char *bbsmenu_url;
 
 
+  /* proxyϢ */
+  char *proxy_url;
+  char *proxy_user;
+  char *proxy_password;
+  gboolean enable_proxy;
+  gboolean enable_proxy_auth;
+
+
   /* network˥åȤ̤ */
   gboolean offline;
 };
@@ -81,13 +88,17 @@ struct _OchushaConfig
  * OCHUSHA_HOMEϢ
  */
 void ochusha_config_prepare_home(OchushaConfig *config);
-char *ochusha_config_find_file(OchushaConfig *config, const char *filename);
-int ochusha_config_open_file(OchushaConfig *config, const char *filename,
+char *ochusha_config_find_file(const OchushaConfig *config,
+			       const char *filename);
+int ochusha_config_open_file(const OchushaConfig *config, const char *filename,
 			     int flags);
 
-int ochusha_config_cache_open_file(OchushaConfig *config, const char *url,
-				   int flags);
-void ochusha_config_cache_unlink_file(OchushaConfig *config, const char *url);
+gboolean ochusha_config_cache_file_exist(const OchushaConfig *config,
+					 const char *url);
+int ochusha_config_cache_open_file(const OchushaConfig *config,
+				   const char *url, int flags);
+void ochusha_config_cache_unlink_file(const OchushaConfig *config,
+				      const char *url);
 
 
 /*
@@ -116,59 +127,6 @@ char *ochusha_utils_get_attribute_string(GHashTable *hash_table,
 					 const char *attr_name);
 
 
-/*
- * ͥåȥϢ
- */
-typedef void NetCallbackFunc(gpointer callback_data);
-
-typedef struct _OchushaNetworkCallbacks
-{
-  NetCallbackFunc *access_started;
-  NetCallbackFunc *access_progressed;
-  NetCallbackFunc *access_completed;
-  NetCallbackFunc *access_terminated;
-  NetCallbackFunc *access_failed;
-} OchushaNetworkCallbacks;
-
-
-typedef enum
-{
-  OCHUSHA_UNKNOWN_STATE,
-  OCHUSHA_DIRECT_ACCESS,
-  OCHUSHA_CACHE_HIT,
-  OCHUSHA_CACHE_IS_OK,
-  OCHUSHA_CACHE_IS_DIRTY,
-  OCHUSHA_ACCESS_OK,
-  OCHUSHA_ACCESS_FAILED
-} OchushaNetworkState;
-
-
-typedef struct _OchushaNetworkStatus
-{
-  volatile OchushaNetworkState state;
-
-  int status_code;
-  char *last_modified;
-} OchushaNetworkStatus;
-
-
-typedef enum
-{
-  OCHUSHA_CACHE_IGNORE,
-  OCHUSHA_CACHE_ONLY,
-  OCHUSHA_CACHE_AS_IS,
-  OCHUSHA_CACHE_TRY_UPDATE,
-  OCHUSHA_CACHE_TRY_REFRESH
-} OchushaCacheMode;
-
-
-OchushaAsyncBuffer *ochusha_read_from_url(OchushaConfig *application,
-					  const char *url,
-					  const char *last_modified,
-					  OchushaCacheMode mode,
-					  OchushaNetworkCallbacks *callbacks,
-					  gpointer callback_data);
-
 #ifdef __cplusplus
 } // extern "C"
 #endif
