@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_table.c,v 1.6 2003/06/20 18:10:06 fuyu Exp $
+ * $Id: ochusha_bbs_table.c,v 1.9 2003/11/04 01:42:04 fuyu Exp $
  */
 
 #include "config.h"
@@ -667,7 +667,11 @@ endElementHandler(void *context, const xmlChar *name)
 	   * ƤSAXѡŪʣǤȤƸƤޤ礬ꡢ
 	   * Ϣ뤹뤿ΰХåեɬפǤ뤫顣
 	   */
-	  sax_context->current_attr_val = G_STRDUP(sax_context->current_attr_val);
+	  if (sax_context->current_attr_val != NULL)
+	    sax_context->current_attr_val
+	      = G_STRDUP(sax_context->current_attr_val);
+	  else
+	    sax_context->current_attr_val = G_STRDUP("");
 	  return;
 	}
       break;	/* 顼 */
@@ -903,22 +907,26 @@ ochusha_bbs_table_read_boardlist_xml(OchushaBBSTable *table,
   if (pathname == NULL)
     return FALSE;
 
-  xmlInitParser();
-
   memset(&sax_handler, 0, sizeof(xmlSAXHandler));
+#if LIBXML_VERSION >= 20600
+  xmlSAX2InitDefaultSAXHandler(&sax_handler, TRUE);
+#else
   initxmlDefaultSAXHandler(&sax_handler, TRUE);
+#endif
 
   sax_handler.getEntity = getEntityHandler;
   sax_handler.startDocument = nopHandler;
   sax_handler.endDocument = nopHandler;
   sax_handler.startElement = startElementHandler;
   sax_handler.endElement = endElementHandler;
+#if LIBXML_VERSION >= 20600
+  sax_handler.startElementNs = NULL;
+  sax_handler.endElementNs = NULL;
+#endif
   sax_handler.characters = charactersHandler;
 
   xmlSAXUserParseFile(&sax_handler, &context, pathname);
 
-  xmlCleanupParser();
-
   cleanup_sax_context(&context);
 
   if (context.state == SAX_ACCEPTED)
