@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_bbs_thread.h,v 1.7 2003/07/13 14:53:51 fuyu Exp $
+ * $Id: ochusha_bbs_thread.h,v 1.8 2003/11/02 21:30:43 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BBS_THREAD_H_
@@ -131,10 +131,10 @@ struct _OchushaBBSThreadClass
 
 struct _OchushaBBSResponse
 {
-  const char *name;
-  const char *mailto;
-  const char *date_id;
-  const char *content;
+  const gchar *name;
+  const gchar *mailto;
+  const gchar *date_id;
+  const gchar *content;
 };
 
 
