@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_2ch.h,v 1.2 2003/05/25 08:46:16 fuyu Exp $
+ * $Id: ochusha_board_2ch.h,v 1.3 2003/11/02 21:32:43 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BOARD_2CH_H_
@@ -55,6 +55,7 @@ struct _OchushaBoard2ch
   OchushaBulletinBoard parent_object;
 
   char *last_modified;	/* Ĥsubject.txtɤ߹߻Last-Modifiedإå */
+  char *cookie;		/* Ǹ˼cookie */
 };
 
 
@@ -69,7 +70,8 @@ struct _OchushaBoard2chClass
 GType ochusha_board_2ch_get_type(void);
 OchushaBulletinBoard *ochusha_board_2ch_new(const gchar *name,
 					    const gchar *url);
-
+const char *ochusha_board_2ch_get_cookie(OchushaBoard2ch *board);
+void ochusha_board_2ch_set_cookie(OchushaBoard2ch *board, const char *cookie);
 
 #ifdef __cplusplus
 } // extern "C"
