@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_board_category.h,v 1.2 2003/05/14 20:11:43 fuyu Exp $
+ * $Id: ochusha_board_category.h,v 1.3 2003/06/20 18:10:06 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_BOARD_CATEGORY_H_
@@ -57,6 +57,9 @@ struct _OchushaBoardCategory
   gchar *name;
 
   GSList *board_list;
+
+  gboolean hidden;		/* İ鱣 */
+  gboolean killed;		/* İ¸˼ΤƤ */
 };
 
 
