@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_config.c,v 1.8 2003/06/12 04:12:43 fuyu Exp $
+ * $Id: ochusha_config.c,v 1.10 2003/11/04 01:42:04 fuyu Exp $
  */
 
 #include "config.h"
@@ -768,21 +768,28 @@ ochusha_read_config_xml(OchushaConfig *config,
       return;
     }
 
-  xmlInitParser();
-
   memset(&sax_handler, 0, sizeof(xmlSAXHandler));
+
+#if LIBXML_VERSION >= 20600
+  xmlSAX2InitDefaultSAXHandler(&sax_handler, TRUE);
+#else
   initxmlDefaultSAXHandler(&sax_handler, TRUE);
+#endif
 
   sax_handler.getEntity = getEntityHandler;
   sax_handler.startDocument = nopHandler;
   sax_handler.endDocument = nopHandler;
   sax_handler.startElement = startElementHandler;
   sax_handler.endElement = endElementHandler;
+#if LIBXML_VERSION >= 20600
+  sax_handler.startElementNs = NULL;
+  sax_handler.endElementNs = NULL;
+#endif
   sax_handler.characters = charactersHandler;
 
   xmlSAXUserParseFile(&sax_handler, &context, pathname);
 
-  xmlCleanupParser();
+  /* xmlCleanupParser(); */
 
   if (context.state == SAX_ACCEPTED)
     {
