@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_network_broker.c,v 1.6 2003/06/22 14:38:47 fuyu Exp $
+ * $Id: ochusha_network_broker.c,v 1.8 2003/11/04 07:55:05 fuyu Exp $
  */
 
 #include "config.h"
@@ -250,6 +250,8 @@ ochusha_network_broker_buffer_status_free(OchushaNetworkBrokerBufferStatus *stat
 {
   if (status->last_modified != NULL)
     G_FREE(status->last_modified);
+  if (status->date != NULL)
+    G_FREE(status->date);
   G_FREE(status);
 }
 
@@ -592,6 +594,7 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
   if (state == ghttp_error || status_code != 200)
     {
+      const char *tmp_header;
       status->status_code = status_code;
 
 #if DEBUG_NETWORK
@@ -613,6 +616,11 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
        *       顼ǤϤʤcallerϥåǤΤȤ
        *       ȤȤǤ롣
        */
+      tmp_header = ghttp_get_header(request, http_hdr_Date);
+      if (tmp_header != NULL)
+	status->date = G_STRDUP(tmp_header);
+      else
+	status->date = NULL;
       ghttp_request_destroy(request);
       args->request = NULL;
       return FALSE;
@@ -786,12 +794,19 @@ http_read_from_url(OchushaNetworkBroker *broker, OchushaAsyncBuffer *buffer)
 
   if (status_code == 200)
     {
-      const char *last_modified
+      
+      const char *tmp_header
 	= ghttp_get_header(request, http_hdr_Last_Modified);
-      if (last_modified != NULL)
-	status->last_modified = G_STRDUP(last_modified);
+      if (tmp_header != NULL)
+	status->last_modified = G_STRDUP(tmp_header);
       else
 	status->last_modified = NULL;
+      tmp_header = ghttp_get_header(request, http_hdr_Date);
+      if (tmp_header != NULL)
+	status->date = G_STRDUP(tmp_header);
+      else
+	status->date = NULL;
+
       status->status_code = status_code;
       g_signal_emit(G_OBJECT(broker),
 		    broker_signals[ACCESS_COMPLETED_SIGNAL],
@@ -1080,7 +1095,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 
       if (status_code == 304 && args->if_modified_since != NULL)
 	{
+	  const char *tmp_header;
 	  status->last_modified = G_STRDUP(args->if_modified_since);
+	  tmp_header = ghttp_get_header(request, http_hdr_Date);
+	  if (tmp_header != NULL)
+	    status->date = G_STRDUP(tmp_header);
+	  else
+	    status->date = NULL;
 	  status->status_code = status_code;
 	  status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_IS_OK;
 	  g_signal_emit(G_OBJECT(args->broker),
@@ -1380,12 +1401,18 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	  status_code = ghttp_status_code(request);
 	  if (status_code == 206)
 	    {	/* ʬžλ */
-	      const char *last_modified
+	      const char *tmp_header
 		= ghttp_get_header(request, http_hdr_Last_Modified);
-	      if (last_modified != NULL)
-		status->last_modified = G_STRDUP(last_modified);
+	      if (tmp_header != NULL)
+		status->last_modified = G_STRDUP(tmp_header);
 	      else
 		status->last_modified = NULL;
+	      tmp_header = ghttp_get_header(request, http_hdr_Date);
+	      if (tmp_header != NULL)
+		status->date = G_STRDUP(tmp_header);
+	      else
+		status->date = NULL;
+
 	      status->status_code = status_code;
 	      g_signal_emit(G_OBJECT(args->broker),
 			    broker_signals[ACCESS_COMPLETED_SIGNAL],
@@ -1412,7 +1439,13 @@ try_update_cache(WorkerThread *employee, OchushaAsyncBuffer *buffer)
 	       * MEMO: ѹʤ(If-Modified-Sinceդ)ʤΤ
 	       *       åϿ
 	       */
+	      const char *tmp_header;
 	      status->status_code = status_code;
+	      tmp_header = ghttp_get_header(request, http_hdr_Date);
+	      if (tmp_header != NULL)
+		status->date = G_STRDUP(tmp_header);
+	      else
+		status->date = NULL;
 	      status->state = OCHUSHA_NETWORK_BROKER_BUFFER_STATE_CACHE_HIT;
 	      g_signal_emit(G_OBJECT(args->broker),
 			    broker_signals[ACCESS_COMPLETED_SIGNAL],
