@@ -23,14 +23,16 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.c,v 1.9 2003/06/22 13:21:43 fuyu Exp $
+ * $Id: ochusha_thread_2ch.c,v 1.12 2003/11/04 07:56:41 fuyu Exp $
  */
 
 #include "config.h"
 
 #include "ochusha_private.h"
 #include "ochusha.h"
+#include "ochusha_board_2ch.h"
 #include "ochusha_thread_2ch.h"
+#include "ochusha_utils_2ch.h"
 
 #include <glib-object.h>
 #include <glib.h>
@@ -38,6 +40,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <unistd.h>
 
 
 #define DEBUG_DAT	0
@@ -148,13 +151,8 @@ ochusha_thread_2ch_class_init(OchushaThread2chClass *klass)
   b_class->check_url = ochusha_thread_2ch_check_url;
   b_class->remove_cache = ochusha_thread_2ch_remove_cache;
 
-#if 0
-  b_class->preview_response = NULL;
-  b_class->post_response = NULL;
-#else
   b_class->preview_response = ochusha_thread_2ch_preview_response;
   b_class->post_response = ochusha_thread_2ch_post_response;
-#endif
 }
 
 
@@ -216,6 +214,12 @@ ochusha_thread_2ch_finalize(GObject *object)
       thread->last_modified = NULL;
     }
 
+  if (thread->date != NULL)
+    {
+      G_FREE(thread->date);
+      thread->date = NULL;
+    }
+
   if (G_OBJECT_CLASS(parent_class)->finalize)
     (*G_OBJECT_CLASS(parent_class)->finalize)(object);
 }
@@ -913,6 +917,13 @@ ochusha_thread_2ch_parse_responses(OchushaBBSThread *thread,
       thread_2ch->last_modified = G_STRDUP(status->last_modified);
     }
 
+  if (status->date != NULL)
+    {
+      if (thread_2ch->date != NULL)
+	G_FREE(thread_2ch->date);
+      thread_2ch->date = G_STRDUP(status->date);
+    }
+
   ochusha_async_buffer_active_unref(buffer, "ochusha_thread_2ch.c: ochusha_thread_2ch_parse_responses");
 
   if (end_thread_cb != NULL)
@@ -958,5 +969,129 @@ ochusha_thread_2ch_post_response(OchushaBBSThread *thread,
 				 OchushaConfig *config,
 				 const OchushaBBSResponse *response)
 {
+  OchushaThread2ch *thread_2ch;
+  OchushaBoard2ch *board_2ch;
+  char *tmp_string = NULL;
+  char *from = NULL;
+  char *mail = NULL;
+  char *message = NULL;
+  const char *bbs;
+  char *key = NULL;
+  char *query = NULL;
+  time_t time;
+  iconv_t converter;
+  OchushaUtils2chPostResult post_result;
+
+  g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread), FALSE);
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(thread->board), FALSE);
+  g_return_val_if_fail(response->name != NULL, FALSE);
+  g_return_val_if_fail(response->mailto != NULL, FALSE);
+  g_return_val_if_fail(response->content != NULL, FALSE);
+
+  converter = iconv_open(ochusha_bulletin_board_get_response_character_encoding(thread->board), "UTF-8");
+  g_return_val_if_fail(converter != (iconv_t)-1, FALSE);
+
+  board_2ch = OCHUSHA_BOARD_2CH(thread->board);
+  thread_2ch = OCHUSHA_THREAD_2CH(thread);
+
+  tmp_string = convert_string(converter, NULL, response->name, -1);
+  from = ochusha_utils_url_encode_string(tmp_string);
+  if (from == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+
+  tmp_string = convert_string(converter, NULL, response->mailto, -1);
+  mail = ochusha_utils_url_encode_string(tmp_string);
+  if (mail == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+
+  tmp_string = convert_string(converter, NULL, response->content, -1);
+  message = ochusha_utils_url_encode_string(tmp_string);
+  if (message == NULL)
+    goto error_exit;
+  G_FREE(tmp_string);
+  tmp_string = NULL;
+
+  bbs = ochusha_bulletin_board_get_id(thread->board);
+
+  tmp_string = (char *)ochusha_bbs_thread_get_id(thread);
+  g_assert(strstr(tmp_string, ".dat"));
+  key = g_strndup(tmp_string, strstr(tmp_string, ".dat") - tmp_string);
+  tmp_string = NULL;
+  if (key == NULL)
+    goto error_exit;
+
+  if (thread_2ch->date != NULL)
+    time = ochusha_utils_get_utc_time(thread_2ch->date);
+  else
+    {
+#if DEBUG_POST
+      fprintf(stderr, "thread_2ch->date == NULL!\n");
+#endif
+      time = ochusha_utils_get_utc_time(thread_2ch->last_modified);
+    }
+
+  if (time == -1)
+    goto error_exit;
+
+  /* XXX: ϡɥǥ󥰤㤦ΤϤäʤġġ*/
+  query = g_strdup_printf("submit=%%8F%%91%%82%%AB%%8D%%9E%%82%%DE&FROM=%s&mail=%s&MESSAGE=%s&bbs=%s&key=%s&time=%ld", from, mail, message, bbs, key, time);
+
+  post_result = ochusha_utils_2ch_try_post(thread, query);
+  if (post_result == OCHUSHA_UTILS_2CH_POST_NO_COOKIE)
+    {
+      sleep(10);
+      post_result = ochusha_utils_2ch_try_post(thread, query);
+    }
+
+#if 0
+  if (post_result == OCHUSHA_UTILS_2CH_POST_MOCHITSUKE)
+    {
+      /* XXX: äݤΤȤͭʤΤ֡ */
+      sleep(30);
+      post_result = ochusha_utils_2ch_try_post(thread, query);
+    }
+#endif
+
+  if (post_result != OCHUSHA_UTILS_2CH_POST_SUCCESS)
+    goto error_exit;
+
+  /* ｪλ */
+  if (tmp_string != NULL)
+    G_FREE(tmp_string);
+  if (from != NULL)
+    G_FREE(from);
+  if (mail != NULL)
+    G_FREE(mail);
+  if (message != NULL)
+    G_FREE(message);
+  if (key != NULL)
+    G_FREE(key);
+  if (query != NULL)
+    G_FREE(query);
+  iconv_close(converter);
+
+  return TRUE;
+
+ error_exit:
+#if DEBUG_POST
+  fprintf(stderr, "Error happen\n");
+#endif
+
+  if (tmp_string != NULL)
+    G_FREE(tmp_string);
+  if (from != NULL)
+    G_FREE(from);
+  if (mail != NULL)
+    G_FREE(mail);
+  if (message != NULL)
+    G_FREE(message);
+  if (key != NULL)
+    G_FREE(key);
+  if (query != NULL)
+    G_FREE(query);
+  iconv_close(converter);
+
   return FALSE;
 }
