@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_thread_2ch.h,v 1.2 2003/05/25 08:46:16 fuyu Exp $
+ * $Id: ochusha_thread_2ch.h,v 1.3 2003/11/02 22:01:15 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_THREAD_2CH_H_
@@ -62,10 +62,11 @@ struct _OchushaThread2ch
   char *base_path; /* "/test/read.cgi/linux/1022744633/" */
   char *post_url;  /* "http://pc.2ch.net/test/read.cgi/linux/1022744633/l10" */
 
-  /* responses[n]: nܤΥ쥹DAToffset */
+  /* responses[n]: (0ϤޤΤ)n+1ܤΥ쥹DAToffset */
   unsigned int *responses;
 
   char *last_modified;	/* DATեɤ߹߻Last-Modifiedإå */
+  char *date;		/* 񤭹߻˻Ȥ */
 
   /* ιŪ˻Ȥ */
   gboolean alive;
