@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.c,v 1.6 2003/07/13 14:53:51 fuyu Exp $
+ * $Id: ochusha_utils_2ch.c,v 1.9 2003/11/04 08:58:38 fuyu Exp $
  */
 
 #include "config.h"
@@ -32,6 +32,7 @@
 #include "ochusha.h"
 #include "ochusha_bbs_table.h"
 #include "ochusha_board_2ch.h"
+#include "ochusha_thread_2ch.h"
 #include "ochusha_utils_2ch.h"
 
 #include "utils.h"
@@ -488,3 +489,119 @@ ochusha_utils_2ch_parse_url(OchushaBBSTable *table, const char *url,
 
   return result;
 }
+
+
+OchushaUtils2chPostResult
+ochusha_utils_2ch_try_post(OchushaBBSThread *thread, const char *message)
+{
+  char uri[PATH_MAX];
+  ghttp_request *request;
+  const char *cookie;
+  const char *new_cookie = NULL;
+  int status_code;
+  OchushaBoard2ch *board_2ch;
+  gboolean post_error = FALSE;
+
+  g_return_val_if_fail(g_snprintf(uri, PATH_MAX, "http://%s/test/bbs.cgi",
+				  thread->board->server) < PATH_MAX,
+		       OCHUSHA_UTILS_2CH_POST_FAILURE);
+  g_return_val_if_fail(OCHUSHA_IS_THREAD_2CH(thread),
+		       OCHUSHA_UTILS_2CH_POST_FAILURE);
+  g_return_val_if_fail(OCHUSHA_IS_BOARD_2CH(thread->board),
+		       OCHUSHA_UTILS_2CH_POST_FAILURE);
+  board_2ch = OCHUSHA_BOARD_2CH(thread->board);
+
+  request = ghttp_request_new();
+
+  ghttp_set_uri(request, uri);
+  ghttp_set_type(request, ghttp_type_post);
+
+  ghttp_set_header(request, http_hdr_Host, thread->board->server);
+  ghttp_set_header(request, http_hdr_User_Agent, OCHUSHA_USER_AGENT);
+
+  /* ɬפʤΤ */
+  ghttp_set_header(request, http_hdr_Accept, "text/xml,application/xml,application/xhtml+xml,text/html;q=0.9,text/plain;q=0.8,video/x-mng,image/png,image/jpeg,image/gif;q=0.2,text/css,*/*;q=0.1");
+  ghttp_set_header(request, http_hdr_Accept_Language, "ja,en-us;q=0.66,en;q=0.33");
+  ghttp_set_header(request, http_hdr_Accept_Charset, "EUC-JP,utf-8;q=0.66,*;q=0.66");
+  ghttp_set_header(request, http_hdr_Connection, "close");
+  ghttp_set_header(request, http_hdr_Referrer,
+		   ochusha_bbs_thread_get_url_to_post_response(thread));
+  ghttp_set_header(request, "Referer",
+		   ochusha_bbs_thread_get_url_to_post_response(thread));
+
+  cookie = ochusha_board_2ch_get_cookie(board_2ch);
+  if (cookie != NULL)
+    {
+#if DEBUG_POST_MOST
+      fprintf(stderr, "Cookie: %s\n", cookie);
+#endif
+      ghttp_set_header(request, "Cookie", cookie);
+    }
+
+  ghttp_set_body(request, (char *)message, strlen(message));
+#if DEBUG_POST_MOST
+  fprintf(stderr, "Post-Body: %s\n", message);
+#endif
+
+  ghttp_prepare(request);
+  if (ghttp_process(request) == ghttp_error)
+    {
+      ghttp_request_destroy(request);
+      ochusha_board_2ch_set_cookie(board_2ch, NULL);
+    }
+
+  status_code = ghttp_status_code(request);
+
+  if (status_code == 200)
+    {
+      const char *body = ghttp_get_body(request);
+      int len = ghttp_get_body_len(request);
+      const char *x_2ch = g_strstr_len(body, len, "2ch_X:");
+
+      if (x_2ch != NULL)
+	{
+#if DEBUG_POST_MOST
+	  char *native_body = g_convert(body, len, "EUC-JP", "CP932",
+					NULL, NULL, NULL);
+	  fprintf(stderr, "Set-Cookie: %s\n",
+		  ghttp_get_header(request, http_hdr_Set_Cookie));
+	  fprintf(stderr, "Result-Body: %s\n", native_body);
+	  g_free(native_body);
+#endif
+	  if (g_strstr_len(x_2ch, len, "2ch_X:cookie") != NULL)
+	    {
+	      new_cookie = ghttp_get_header(request, http_hdr_Set_Cookie);
+	      if (new_cookie != NULL && *new_cookie != '\0')
+		{
+		  char *pos = strchr(new_cookie, ';');
+		  if (pos != NULL)
+		    {
+		      char *tmp_cookie = g_strndup(new_cookie,
+						   pos - new_cookie);
+		      ochusha_board_2ch_set_cookie(board_2ch, tmp_cookie);
+		      g_free(tmp_cookie);
+		    }
+		}
+	    }
+	  else
+	    {
+#if DEBUG_POST
+	      char *native_body = g_convert(body, len, "EUC-JP", "CP932",
+					    NULL, NULL, NULL);
+	      fprintf(stderr, "Set-Cookie: %s\n",
+		      ghttp_get_header(request, http_hdr_Set_Cookie));
+	      fprintf(stderr, "Result-Body: %s\n", native_body);
+	      g_free(native_body);
+#endif
+	      post_error = TRUE;
+	    }
+	}
+    }
+
+  ghttp_request_destroy(request);
+
+  if (new_cookie != NULL)
+    return OCHUSHA_UTILS_2CH_POST_NO_COOKIE;
+
+  return post_error ? OCHUSHA_UTILS_2CH_POST_FAILURE : OCHUSHA_UTILS_2CH_POST_SUCCESS;
+}
