@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: ochusha_utils_2ch.h,v 1.2 2003/05/25 08:46:16 fuyu Exp $
+ * $Id: ochusha_utils_2ch.h,v 1.3 2003/11/02 22:01:15 fuyu Exp $
  */
 
 #ifndef _OCHUSHA_UTILS_2CH_H_
@@ -65,6 +65,19 @@ gboolean ochusha_utils_2ch_parse_url(OchushaBBSTable *table, const char *url,
 				     unsigned int *from_p, unsigned int *to_p,
 				     char **thread_part_p);
 
+typedef enum
+{
+  OCHUSHA_UTILS_2CH_POST_SUCCESS,
+  OCHUSHA_UTILS_2CH_POST_NO_COOKIE,
+  OCHUSHA_UTILS_2CH_POST_MOCHITSUKE,
+  OCHUSHA_UTILS_2CH_POST_FAILURE,
+} OchushaUtils2chPostResult;
+
+
+OchushaUtils2chPostResult ochusha_utils_2ch_try_post(OchushaBBSThread *thread,
+						     const char *message);
+
+
 #ifdef __cplusplus
 } // extern "C"
 #endif
