@@ -23,7 +23,7 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- * $Id: utils.c,v 1.9 2003/07/15 05:37:42 fuyu Exp $
+ * $Id: utils.c,v 1.12 2003/11/02 22:01:15 fuyu Exp $
  */
 
 #define OCHUSHA_UTILS_IMPLEMENTATION
@@ -51,6 +51,8 @@
 #include <string.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <time.h>
+
 
 iconv_t utf8_to_native = 0;	/* ǥХå */
 
@@ -160,8 +162,10 @@ convert_string(iconv_t converter, iconv_helper *helper,
 	}
       else
 	{
+#if DEBUG_ICONV
 	  fprintf(stderr, "iconv failed(errno = %d).\n", errno);
 	  fprintf(stderr, "character code = 0x%02x\n", (int)*inbuf);
+#endif
 	  if (buffer != default_buffer)
 	    G_FREE(buffer);
 	  return NULL;
@@ -181,8 +185,10 @@ convert_string(iconv_t converter, iconv_helper *helper,
 	    }
 	  else
 	    {
+#if DEBUG_ICONV
 	      fprintf(stderr, "iconv failed(errno = %d).\n", errno);
 	      fprintf(stderr, "character code = 0x%02x\n", (int)*inbuf);
+#endif
 	      if (buffer != default_buffer)
 		G_FREE(buffer);
 	      return NULL;
@@ -335,16 +341,83 @@ ochusha_utils_url_extract_http_absolute_path(const char *url)
 char *
 ochusha_utils_url_encode_string(const char *src)
 {
-  int src_len = strlen(src);
-  char *buffer = (char *)G_MALLOC(src_len * 3 + 1);
-  const unsigned char *cur_src = src;
-  char *cur_dst = buffer;
-  while (*cur_src != '\0')
+  int src_len;
+  int buffer_len;
+  const char *src_pos;
+  char *buf_pos;
+  char *buf_tail;
+  char *buffer;
+  unsigned char c;
+  gboolean expand_buf;
+
+  g_return_val_if_fail(src != NULL, NULL);
+
+  src_len = strlen(src);
+  buffer_len = src_len * 3 + 1;
+  buffer = (char *)G_MALLOC(buffer_len);
+  buf_tail = buffer + buffer_len - 1;
+  src_pos = src;
+  buf_pos = buffer;
+  expand_buf = FALSE;
+
+#if DEBUG_UTILS
+  fprintf(stderr, "url_encode: src=\"%s\"\n", src);
+#endif
+
+  while ((c = *src_pos) != '\0')
     {
-      sprintf(cur_dst, "%%%02X", *cur_src++);
-      cur_dst += 3;
+      if (expand_buf)
+	{
+	  int result_len = buf_pos - buffer;
+#if DEBUG_UTILS
+	  fprintf(stderr, "expand_buf@url_encode: buffer_len %d => %d\n",
+		  buffer_len, buffer_len * 2);
+#endif
+	  buffer_len *= 2;
+	  buffer = (char *)G_REALLOC(buffer, buffer_len);
+	  buf_tail = buffer + buffer_len - 1;
+	  buf_pos = buffer + result_len;
+	  expand_buf = FALSE;
+	}
+
+      if (g_ascii_isalnum(c)
+	  || c == '*' || c == '-' || c == '.' || c == '@' || c == '_')
+	{
+	  if (buf_pos >= buf_tail)
+	    {
+	      expand_buf = TRUE;
+	      continue;	/* bufferĥƤľ: ꤽˤʤʡ */
+	    }
+	  *buf_pos++ = c;
+	}
+      else if (c == ' ')
+	{
+	  if (buf_pos >= buf_tail)
+	    {
+	      expand_buf = TRUE;
+	      continue;	/* bufferĥƤľ: ꤽˤʤʡ */
+	    }
+	  *buf_pos++ = '+';
+	}
+      else
+	{
+	  int left = buf_tail - buf_pos;
+	  if (left < 4)
+	    {
+	      expand_buf = TRUE;
+	      continue;	/* bufferĥƤľ: ꤽˤʤʡ */
+	    }
+	  buf_pos += g_snprintf(buf_pos, left, "%%%02X", c);
+	}
+      src_pos++;
     }
-  *cur_dst = '\0';
+
+  g_assert(buf_pos <= buf_tail);
+  *buf_pos = '\0';
+
+#if DEBUG_UTILS
+  fprintf(stderr, "url_encode: \"%s\"\n", buffer);
+#endif
 
   return buffer;
 }
@@ -380,6 +453,30 @@ ochusha_utils_url_decode_string(const char *src)
 }
 
 
+/*
+ * ochusha_utils_get_utc_time
+ *
+ * Ϳ줿ʸɽʸȤƲᤷUTC֤
+ */
+time_t
+ochusha_utils_get_utc_time(const char *date_string)
+{
+  static char *lc_time = NULL;
+  struct tm tm;
+
+  if (lc_time == NULL)
+    {
+      lc_time = setlocale(LC_TIME, "C");
+      g_return_val_if_fail(lc_time != NULL, -1);
+    }
+
+  g_return_val_if_fail(date_string != NULL && *date_string != '\0', -1);
+  g_return_val_if_fail(strptime(date_string, "%a, %d %b %Y %T %Z", &tm)!= NULL,
+		       -1);
+  return mktime(&tm);
+}
+
+
 /*
  * mkdir_p
  *
@@ -1374,8 +1471,8 @@ cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
 		     char **outbuf, size_t *outbytesleft)
 {
   const char *utf8_string = NULL;
-  int first;
-  int second;
+  unsigned char first;
+  unsigned char second;
 
   if (*inbytesleft <= 2)
     {
@@ -1383,8 +1480,13 @@ cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
       return -1;
     }
 
+#if 1
+  first = (*inbuf)[0];
+  second = (*inbuf)[1];
+#else
   first = (*inbuf)[0] & 0xff;
   second = (*inbuf)[1] & 0xff;
+#endif
 
 #if DEBUG_ICONV
   fprintf(stderr, "first=%02x second=%02x\n", first, second);
@@ -1433,7 +1535,11 @@ cp932_to_utf8_helper(const char **inbuf, size_t *inbytesleft,
   if (utf8_string == NULL)
     {
       /* Ʀ(={ 0xe2, 0x96, 0xa1 })ɤ*/
+#if DEBUG_ICONV
+      fprintf(stderr, "first=%02x second=%02x\n", first, second);
+#endif
       utf8_string = "\342\226\241";
+      first = '\0';
     }
 
   if ((first & 0x80) != 0)
